#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: dna_network_devices_query_count
short_description: Resource module for Dna Network Devices
  Query Count
description:
  - Manage operation create of the resource Dna Network
    Devices Query Count. - > Gets the total number Network
    Devices based on the provided complex filters and
    aggregation functions. For detailed information
    about the usage of the API, please refer to the
    Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    AssuranceNetworkDevices-2.0.1-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: End Time.
    type: int
  filters:
    description: Dna Network Devices Query Count's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: str
    type: list
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetsTheTotalNumberNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctions
    description: Complete reference of the GetsTheTotalNumberNetworkDevicesBasedOnTheProvidedComplexFiltersAndAggregationFunctions
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-the-total-number-network-devices-based-on-the-provided-complex-filters-and-aggregation-functions
notes:
  - SDK Method used are
    devices.Devices.gets_the_total_number_network_devices_based_on_the_provided_complex_filters_and_aggregation_functions,
  - Paths used are
    post /dna/data/api/v1/networkDevices/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.dna_network_devices_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    filters:
      - key: string
        operator: string
        value: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_devices_device_controllability_settings
short_description: Resource module for Network Devices
  Device Controllability Settings
description:
  - Manage operation update of the resource Network
    Devices Device Controllability Settings. - > Device
    Controllability is a system-level process on Catalyst
    Center that enforces state synchronization for some
    device-layer features. Its purpose is to aid in
    the deployment of required network settings that
    Catalyst Center needs to manage devices. Changes
    are made on network devices during discovery, when
    adding a device to Inventory, or when assigning
    a device to a site. If changes are made to any settings
    that are under the scope of this process, these
    changes are applied to the network devices during
    the Provision and Update Telemetry Settings operations,
    even if Device Controllability is disabled. The
    following device settings will be enabled as part
    of Device Controllability when devices are discovered.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  autocorrectTelemetryConfig:
    description: If it is true, autocorrect telemetry
      config is enabled. If it is false, autocorrect
      telemetry config is disabled. The autocorrect
      telemetry config feature is supported only when
      device controllability is enabled.
    type: bool
  deviceControllability:
    description: If it is true, device controllability
      is enabled. If it is false, device controllability
      is disabled.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      UpdateDeviceControllabilitySettings
    description: Complete reference of the UpdateDeviceControllabilitySettings
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-device-controllability-settings
notes:
  - SDK Method used are
    site_design.SiteDesign.update_device_controllability_settings,
  - Paths used are
    put /dna/intent/api/v1/networkDevices/deviceControllability/settings,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.network_devices_device_controllability_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    autocorrectTelemetryConfig: true
    deviceControllability: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "url": "string",
        "taskId": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_trend_analytics
short_description: Resource module for Energy Trend
  Analytics
description:
  - Manage operation create of the resource Energy Trend
    Analytics. - > Retrieve the energy trend analytics
    data related to device energy consumption for all
    devices, including network devices and clients assigned
    to specific sites. For detailed information about
    the usage of the API, please refer to the Open API
    specification document - https //github.com/cisco-en-programmability/catalyst-
    center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-deviceEnergy_1.0-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Energy Trend Analytics's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Energy Trend Analytics's filters.
    elements: dict
    suboptions:
      filters:
        description: Energy Trend Analytics's filters.
        elements: dict
        suboptions:
          key:
            description: Key.
            type: str
          operator:
            description: Operator.
            type: str
          value:
            description: Value.
            elements: str
            type: list
        type: list
      logicalOperator:
        description: Logical Operator.
        type: str
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  page:
    description: Energy Trend Analytics's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      timestampOrder:
        description: Timestamp Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Know Your
      Network GetEnergyTrendAnalytics
    description: Complete reference of the GetEnergyTrendAnalytics
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-energy-trend-analytics
notes:
  - SDK Method used are
    know_your_network.KnowYourNetwork.get_energy_trend_analytics,
  - Paths used are
    post /dna/data/api/v1/energy/trendAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.energy_trend_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - filters:
          - key: string
            operator: string
            value:
              - string
        logicalOperator: string
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    page:
      limit: 0
      offset: 0
      timestampOrder: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "groups": [
            {
              "id": "string",
              "attributes": [
                {
                  "name": "string",
                  "value": "string"
                }
              ],
              "aggregateAttributes": [
                {
                  "name": "string",
                  "function": "string",
                  "value": 0
                }
              ]
            }
          ],
          "timestamp": 0
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timestampOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_port_assignments
short_description: Resource module for Sda Port Assignments
description:
  - Manage operations create, update and delete of the
    resource Sda Port Assignments.
  - Adds port assignments based on user input.
  - Deletes a port assignment based on id.
  - Deletes port assignments based on user input.
  - Updates port assignments based on user input.
version_added: '6.14.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  dataVlanName:
    description: DataVlanName query parameter. Data
      VLAN name of the port assignment.
    type: str
  fabricId:
    description: FabricId query parameter. ID of the
      fabric the device is assigned to.
    type: str
  id:
    description: Id path parameter. ID of the port assignment.
    type: str
  interfaceName:
    description: InterfaceName query parameter. Interface
      name of the port assignment.
    type: str
  networkDeviceId:
    description: NetworkDeviceId query parameter. Network
      device ID of the port assignment.
    type: str
  payload:
    description: Sda Port Assignments's payload.
    elements: dict
    suboptions:
      allowedVlanRanges:
        description: Allowed VLAN of the port assignment,
          this option is only applicable to TRUNKING_DEVICE
          connectedDeviceType. (VLAN must be between
          1 and 4094 (Ex 100,200,300-400) or 'all'.
          In cases value not set when connectedDeviceType
          is TRUNKING_DEVICE, default value will be
          'all').
        type: str
      authenticateTemplateName:
        description: Authenticate template name of the
          port assignment.
        type: str
      connectedDeviceType:
        description: Connected device type of the port
          assignment.
        type: str
      dataVlanName:
        description: Data VLAN name of the port assignment.
        type: str
      fabricId:
        description: ID of the fabric the device is
          assigned to.
        type: str
      interfaceDescription:
        description: Interface description of the port
          assignment.
        type: str
      interfaceName:
        description: Interface name of the port assignment.
        type: str
      nativeVlanId:
        description: Integer example 1 Native VLAN of
          the port assignment, this option is only applicable
          to TRUNKING_DEVICE connectedDeviceType. (VLAN
          must be between 1 and 4094. In cases value
          not set when connectedDeviceType is TRUNKING_DEVICE,
          default value will be 1).
        type: int
      networkDeviceId:
        description: Network device ID of the port assignment.
        type: str
      securityGroupName:
        description: Security group name of the port
          assignment.
        type: str
      voiceVlanName:
        description: Voice VLAN name of the port assignment.
        type: str
    type: list
  voiceVlanName:
    description: VoiceVlanName query parameter. Voice
      VLAN name of the port assignment.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA AddPortAssignments
    description: Complete reference of the AddPortAssignments
      API.
    link: https://developer.cisco.com/docs/dna-center/#!add-port-assignments
  - name: Cisco DNA Center documentation for SDA DeletePortAssignmentById
    description: Complete reference of the DeletePortAssignmentById
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-port-assignment-by-id
  - name: Cisco DNA Center documentation for SDA DeletePortAssignments
    description: Complete reference of the DeletePortAssignments
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-port-assignments
  - name: Cisco DNA Center documentation for SDA UpdatePortAssignments
    description: Complete reference of the UpdatePortAssignments
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-port-assignments
notes:
  - SDK Method used are
    sda.Sda.add_port_assignments,
    sda.Sda.delete_port_assignment_by_id,
    sda.Sda.update_port_assignments,
  - Paths used are
    post /dna/intent/api/v1/sda/portAssignments,
    delete /dna/intent/api/v1/sda/portAssignments,
    delete
    /dna/intent/api/v1/sda/portAssignments/{id},
    put
    /dna/intent/api/v1/sda/portAssignments,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.sda_port_assignments:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - allowedVlanRanges: string
        authenticateTemplateName: string
        connectedDeviceType: string
        dataVlanName: string
        fabricId: string
        interfaceDescription: string
        interfaceName: string
        nativeVlanId: 0
        networkDeviceId: string
        securityGroupName: string
        voiceVlanName: string
- name: Update all
  cisco.dnac.sda_port_assignments:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    payload:
      - allowedVlanRanges: string
        authenticateTemplateName: string
        connectedDeviceType: string
        dataVlanName: string
        fabricId: string
        id: string
        interfaceDescription: string
        interfaceName: string
        nativeVlanId: 0
        networkDeviceId: string
        scalableGroupName: string
        voiceVlanName: string
- name: Delete all
  cisco.dnac.sda_port_assignments:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    dataVlanName: string
    fabricId: string
    interfaceName: string
    networkDeviceId: string
    voiceVlanName: string
- name: Delete by id
  cisco.dnac.sda_port_assignments:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_network_device_id_config_features_intended_deploy
short_description: Resource module for Wired Network
  Devices Network Device Id Config Features Intended
  Deploy
description:
  - Manage operation create of the resource Wired Network
    Devices Network Device Id Config Features Intended
    Deploy. - > Deploy the intended configuration features
    on a wired device. This can be used only if the
    provisioning settings do not require Preview or
    ITSM Approval before deploying configurations on
    network devices. The API /intent/api/v1/provisioningSettings
    can be used to get or update provisioning settings.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  networkDeviceId:
    description: NetworkDeviceId path parameter. Network
      device ID of the wired device to provision. The
      API /intent/api/v1/network-device can be used
      to get the network device ID.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wired DeployTheIntendedConfigurationFeaturesOnAWiredDevice
    description: Complete reference of the DeployTheIntendedConfigurationFeaturesOnAWiredDevice
      API.
    link: https://developer.cisco.com/docs/dna-center/#!deploy-the-intended-configuration-features-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.deploy_the_intended_configuration_features_on_a_wired_device,
  - Paths used are
    post /dna/intent/api/v1/wired/networkDevices/{networkDeviceId}/configFeatures/intended/deploy,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wired_network_devices_network_device_id_config_features_intended_deploy:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    networkDeviceId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: interfaces_count_info
short_description: Information module for Interfaces
  Count
description:
  - Get all Interfaces Count. - > Gets the total Network
    device interface counts. For detailed information
    about the usage of the API, please refer to the
    Open API specification document - https //github.com/cisco-en-programmability/catalyst-center-
    api-specs/blob/main/Assurance/CE_Cat_Center_Org-interfaces-2.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*/San*, */San,
        /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (`*`)
        character search support. E.g. `*uuid*, *uuid,
        uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) Examples `?siteId=id1` (single
        id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
  networkDeviceId:
    description:
      - >
        NetworkDeviceId query parameter. The list of
        Network Device Uuids. (Ex. `6bef213c-19ca-4170-8375-b694e251101c`)
        Examples `networkDeviceId=6bef213c-19ca-4170-8375-b694e251101c`
        (single networkDeviceId requested) `networkDeviceId=6bef213c-19ca-4170-8375-
        b694e251101c&networkDeviceId=32219612-819e-4b5e-a96b-cf22aca13dd9&networkDeviceId=2541e9a7-b80d-4955-
        8aa2-79b233318ba0` (multiple networkDeviceIds
        with & separator).
    type: str
  networkDeviceIpAddress:
    description:
      - >
        NetworkDeviceIpAddress query parameter. The
        list of Network Device management IP Address.
        (Ex. `121.1.1.10`) This field supports wildcard
        (`*`) character-based search. Ex `*1.1*` or
        `1.1*` or `*1.1` Examples `networkDeviceIpAddress=121.1.1.10`
        `networkDeviceIpAddress=121.1.1.10&networkDeviceIpAddress=1
        72.20.1.10&networkDeviceIpAddress=10.10.20.10`
        (multiple networkDevice IP Address with & separator).
    type: str
  networkDeviceMacAddress:
    description:
      - >
        NetworkDeviceMacAddress query parameter. The
        list of Network Device MAC Address. (Ex. `64
        f6 9d 07 9a 00`) This field supports wildcard
        (`*`) character-based search. Ex `*AB AB AB*`
        or `AB AB AB*` or `*AB AB AB` Examples `networkDeviceMacAddress=64
        f6 9d 07 9a 00` `networkDeviceMacAddress=64
        f6 9d 07 9a 00&networkDeviceMacAddress=70 56
        9d 07 ac 77` (multiple networkDevice MAC addresses
        with & separator).
    type: str
  interfaceId:
    description:
      - >
        InterfaceId query parameter. The list of Interface
        Uuids. (Ex. `6bef213c-19ca-4170-8375-b694e251101c`)
        Examples `interfaceId=6bef213c-19ca-4170-8375-b694e251101c`
        (single interface uuid ) `interfaceId=6bef21
        3c-19ca-4170-8375-b694e251101c&32219612-819e-4b5e-a96b-cf22aca13dd9&2541e9a7-b80d-4955-8aa2-
        79b233318ba0` (multiple Interface uuid with
        & separator).
    type: str
  interfaceName:
    description:
      - >
        InterfaceName query parameter. The list of Interface
        name (Ex. `GigabitEthernet1/0/1`) This field
        supports wildcard (`*`) character-based search.
        Ex `*1/0/1*` or `1/0/1*` or `*1/0/1` Examples
        `interfaceNames=GigabitEthernet1/0/1` (single
        interface name) `interfaceNames=GigabitEthernet1/0/1&GigabitEthernet2/0/1&GigabitEthernet3/0/1`
        (multiple interface names with & separator).
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Devices
      GetsTheTotalNetworkDeviceInterfaceCountsInTheSpecified
      TimeRangeWhenThereIsNoStartAndEndTimeSpecifiedReturnsTheLatestInterfacesTotalCount
    description:
      >
      Complete reference of the
      GetsTheTotalNetworkDeviceInterfaceCountsInTheSpecified
      TimeRangeWhenThereIsNoStartAndEndTimeSpecifiedReturnsTheLatestInterfacesTotalCount
      API.
    link: https://developer.cisco.com/docs/dna-center/#!gets-the-total-network-device-interface-counts-in-the-specified-time-range-
          when-there-is-no-start-and-end-time-specified-returns-the-latest-interfaces-total-count
notes:
  - SDK Method used are
    devices.Devices.gets_the_total_network_device_interface_counts,
  - Paths used are
    get /dna/data/api/v1/interfaces/count,
"""

EXAMPLES = r"""
---
- name: Get all Interfaces Count
  cisco.dnac.interfaces_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    siteHierarchy: string
    siteHierarchyId: string
    siteId: string
    networkDeviceId: string
    networkDeviceIpAddress: string
    networkDeviceMacAddress: string
    interfaceId: string
    interfaceName: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: security_advisories_results_advisories_id_info
short_description: Information module for Security Advisories
  Results Advisories Id
description:
  - Get Security Advisories Results Advisories Id by
    id.
  - Get security advisory affecting the network devices
    by Id.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Id of the security advisory.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Compliance
      GetSecurityAdvisoryAffectingTheNetworkDevicesById
    description: Complete reference of the GetSecurityAdvisoryAffectingTheNetworkDevicesById
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-security-advisory-affecting-the-network-devices-by-id
notes:
  - SDK Method used are
    compliance.Compliance.get_security_advisory_affecting_the_network_devices_by_id,
  - Paths used are
    get /dna/intent/api/v1/securityAdvisories/results/advisories/{id},
"""

EXAMPLES = r"""
---
- name: Get Security Advisories Results Advisories Id
    by id
  cisco.dnac.security_advisories_results_advisories_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "deviceCount": 0,
        "cveIds": [
          "string"
        ],
        "publicationUrl": "string",
        "cvssBaseScore": 0,
        "securityImpactRating": "string",
        "firstFixedVersionsList": [
          {
            "vulnerableVersion": "string",
            "fixedVersions": [
              "string"
            ]
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_network_device_id_assign_anchor_managed_ap_locations
short_description: Resource module for Wireless Settings
  Network Device Id Assign Anchor Managed Ap Locations
description:
  - Manage operation create of the resource Wireless
    Settings Network Device Id Assign Anchor Managed
    Ap Locations. - > This API allows user to assign
    Anchor Managed AP Locations for WLC by device ID.
    The payload should always be a complete list. The
    Managed AP Locations included in the payload will
    be fully processed for both addition and deletion.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  anchorManagedAPLocationsSiteIds:
    description: This API allows user to assign Anchor
      Managed AP Locations for WLC by device ID. The
      payload should always be a complete list. The
      Managed AP Locations included in the payload will
      be fully processed for both addition and deletion.
      - When anchor managed location array present then
      it will add the anchor managed locations.
    elements: str
    type: list
  networkDeviceId:
    description: NetworkDeviceId path parameter. Network
      Device ID. This value can be obtained by using
      the API call GET /dna/intent/api/v1/network-device/ip-address/${ipAddress}.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      AssignAnchorManagedAPLocationsForWLC
    description: Complete reference of the AssignAnchorManagedAPLocationsForWLC
      API.
    link: https://developer.cisco.com/docs/dna-center/#!assign-anchor-managed-ap-locations-for-wlc
notes:
  - SDK Method used are
    wireless.Wireless.assign_anchor_managed_ap_locations_for_w_l_c,
  - Paths used are
    post /dna/intent/api/v1/wirelessSettings/{networkDeviceId}/assignAnchorManagedApLocations,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_settings_network_device_id_assign_anchor_managed_ap_locations:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    anchorManagedAPLocationsSiteIds:
      - string
    networkDeviceId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: icap_clients_id_stats
short_description: Resource module for Icap Clients
  Id Stats
description:
  - Manage operation create of the resource Icap Clients
    Id Stats. - > Retrieves the time series statistics
    of a specific client by applying complex filters.
    If startTime and endTime are not provided, the API
    defaults to the last 24 hours. For detailed information
    about the usage of the API, please refer to the
    Open API specification document - https //github.com/cisco-en-
    programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-icap-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  endTime:
    description: End Time.
    type: int
  filters:
    description: Icap Clients Id Stats's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: int
    type: list
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. Id is the client
      mac address. It can be specified in one of the
      notational conventions 01 23 45 67 89 AB or 01-23-45-67-89-AB
      or 0123.4567.89AB and is case insensitive.
    type: str
  page:
    description: Icap Clients Id Stats's page.
    suboptions:
      limit:
        description: Limit.
        type: int
      offset:
        description: Offset.
        type: int
      timeSortOrder:
        description: Time Sort Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Sensors
      RetrievesSpecificClientStatisticsOverSpecifiedPeriodOfTime
    description: Complete reference of the RetrievesSpecificClientStatisticsOverSpecifiedPeriodOfTime
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-specific-client-statistics-over-specified-period-of-time
notes:
  - SDK Method used are
    sensors.Sensors.retrieves_specific_client_statistics_over_specified_period_of_time,
  - Paths used are
    post /dna/data/api/v1/icap/clients/{id}/stats,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.icap_clients_id_stats:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    endTime: 0
    filters:
      - key: string
        operator: string
        value: 0
    headers: '{{my_headers | from_json}}'
    id: string
    page:
      limit: 0
      offset: 0
      timeSortOrder: string
    startTime: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "clientMac": "string",
          "apMac": "string",
          "radioId": 0,
          "timestamp": 0,
          "band": "string",
          "ssid": "string",
          "rssi": 0,
          "snr": 0,
          "txBytes": 0,
          "rxBytes": 0,
          "rxPackets": 0,
          "txPackets": 0,
          "rxMgmtPackets": 0,
          "txMgmtPackets": 0,
          "rxDataPackets": 0,
          "txDataPackets": 0,
          "txUnicastDataPackets": 0,
          "rxCtrlPackets": 0,
          "txCtrlPackets": 0,
          "rxRetries": 0,
          "rxRate": 0,
          "txRate": 0,
          "clientIp": "string"
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "timeSortOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: clients_trend_analytics_id
short_description: Resource module for Clients Trend
  Analytics Id
description:
  - Manage operation create of the resource Clients
    Trend Analytics Id. - > Retrieves the time series
    information of a specific client by applying complex
    filters, aggregate functions, and grouping. The
    data will be grouped based on the specified trend
    time interval. For detailed information about the
    usage of the API, please refer to the Open API specification
    document - https //github.com/cisco-en- programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-clients1-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aggregateAttributes:
    description: Clients Trend Analytics Id's aggregateAttributes.
    elements: dict
    suboptions:
      function:
        description: Function.
        type: str
      name:
        description: Name.
        type: str
    type: list
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  filters:
    description: Clients Trend Analytics Id's filters.
    elements: dict
    suboptions:
      key:
        description: Key.
        type: str
      operator:
        description: Operator.
        type: str
      value:
        description: Value.
        type: int
    type: list
  groupBy:
    description: Group By.
    elements: str
    type: list
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. Id is the client
      mac address. It can be specified in one of the
      notational conventions 01 23 45 67 89 AB or 01-23-45-67-89-AB
      or 0123.4567.89AB and is case insensitive.
    type: str
  page:
    description: Clients Trend Analytics Id's page.
    suboptions:
      cursor:
        description: Cursor.
        type: str
      limit:
        description: Limit.
        type: int
      timeSortOrder:
        description: Time Sort Order.
        type: str
    type: dict
  startTime:
    description: Start Time.
    type: int
  trendInterval:
    description: Trend Interval.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Clients
      RetrievesSpecificClientInformationOverASpecifiedPeriodOfTime
    description: Complete reference of the RetrievesSpecificClientInformationOverASpecifiedPeriodOfTime
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-specific-client-information-over-a-specified-period-of-time
notes:
  - SDK Method used are
    clients.Clients.retrieves_specific_client_information_over_a_specified_period_of_time,
  - Paths used are
    post /dna/data/api/v1/clients/{id}/trendAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.clients_trend_analytics_id:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    aggregateAttributes:
      - function: string
        name: string
    attributes:
      - string
    endTime: 0
    filters:
      - key: string
        operator: string
        value: 0
    groupBy:
      - string
    headers: '{{my_headers | from_json}}'
    id: string
    page:
      cursor: string
      limit: 0
      timeSortOrder: string
    startTime: 0
    trendInterval: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "timestamp": 0,
          "groups": [
            {
              "id": "string",
              "attributes": [
                {
                  "name": "string",
                  "value": 0
                }
              ],
              "aggregateAttributes": [
                {
                  "name": "string",
                  "function": "string",
                  "value": 0
                }
              ]
            }
          ]
        }
      ],
      "page": {
        "limit": 0,
        "cursor": "string",
        "count": 0,
        "timeSortOrder": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_rf_profiles
short_description: Resource module for Wireless Settings
  Rf Profiles
description:
  - Manage operations create, update and delete of the
    resource Wireless Settings Rf Profiles.
  - This API allows the user to create a custom RF Profile.
  - This API allows the user to delete a custom RF Profile.
  - This API allows the user to update a custom RF Profile.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  defaultRfProfile:
    description: True if RF Profile is default, else
      False. Maximum of only 1 RF Profile can be marked
      as default at any given time.
    type: bool
  enableRadioType6GHz:
    description: True if 6 GHz radio band is enabled
      in the RF Profile, else False.
    type: bool
  enableRadioTypeA:
    description: True if 5 GHz radio band is enabled
      in the RF Profile, else False.
    type: bool
  enableRadioTypeB:
    description: True if 2.4 GHz radio band is enabled
      in the RF Profile, else False.
    type: bool
  id:
    description: Id path parameter. RF Profile ID.
    type: str
  radioType6GHzProperties:
    description: Wireless Settings Rf Profiles's radioType6GHzProperties.
    suboptions:
      broadcastProbeResponseInterval:
        description: Broadcast Probe Response Interval
          of 6 GHz radio band.
        type: int
      coverageHoleDetectionProperties:
        description: Wireless Settings Rf Profiles's
          coverageHoleDetectionProperties.
        suboptions:
          chdClientLevel:
            description: Coverage Hole Detection Client
              Level.
            type: int
          chdDataRssiThreshold:
            description: Coverage Hole Detection Data
              Rssi Threshold.
            type: int
          chdExceptionLevel:
            description: Coverage Hole Detection Exception
              Level(%).
            type: int
          chdVoiceRssiThreshold:
            description: Coverage Hole Detection Voice
              Rssi Threshold.
            type: int
        type: dict
      customRxSopThreshold:
        description: RX-SOP threshold custom configuration
          of 6 GHz radio band.
        type: int
      dataRates:
        description: Data rates of 6 GHz radio band
          passed in comma separated format without any
          spaces. Permissible values 6, 9, 12, 18, 24,
          36, 48, 54.
        type: str
      discoveryFrames6GHz:
        description: Discovery Frames of 6 GHz radio
          band.
        type: str
      enableStandardPowerService:
        description: True if Standard Power Service
          is enabled, else False.
        type: bool
      fraPropertiesC:
        description: Wireless Settings Rf Profiles's
          fraPropertiesC.
        suboptions:
          clientResetCount:
            description: Client Reset Count of 6 GHz
              radio band.
            type: int
          clientUtilizationThreshold:
            description: Client Utilization Threshold
              of 6 GHz radio band.
            type: int
        type: dict
      mandatoryDataRates:
        description: Mandatory data rates of 6 GHz radio
          band passed in comma separated format without
          any spaces and must be a subset of selected
          dataRates with maximum of 2 values. Permissible
          values 6, 9, 12, 18, 24, 36, 48, 54.
        type: str
      maxDbsWidth:
        description: Maximum DBS Width (Permissible
          Values 20,40,80,160,320).
        type: int
      maxPowerLevel:
        description: Maximum power level of 6 GHz radio
          band.
        type: int
      maxRadioClients:
        description: Client Limit of 6 GHz radio band.
        type: int
      minDbsWidth:
        description: Minimum DBS Width (Permissible
          Values 20,40,80,160,320).
        type: int
      minPowerLevel:
        description: Minimum power level of 6 GHz radio
          band.
        type: int
      multiBssidProperties:
        description: Wireless Settings Rf Profiles's
          multiBssidProperties.
        suboptions:
          dot11axParameters:
            description: Wireless Settings Rf Profiles's
              dot11axParameters.
            suboptions:
              muMimoDownLink:
                description: MU-MIMO Downlink.
                type: bool
              muMimoUpLink:
                description: MU-MIMO Uplink.
                type: bool
              ofdmaDownLink:
                description: OFDMA Downlink.
                type: bool
              ofdmaUpLink:
                description: OFDMA Uplink.
                type: bool
            type: dict
          dot11beParameters:
            description: Wireless Settings Rf Profiles's
              dot11beParameters.
            suboptions:
              muMimoDownLink:
                description: MU-MIMO Downlink.
                type: bool
              muMimoUpLink:
                description: MU-MIMO Uplink.
                type: bool
              ofdmaDownLink:
                description: OFDMA Downlink.
                type: bool
              ofdmaMultiRu:
                description: OFDMA Multi-RU.
                type: bool
              ofdmaUpLink:
                description: OFDMA Uplink.
                type: bool
            type: dict
          targetWakeTime:
            description: Target Wake Time.
            type: bool
          twtBroadcastSupport:
            description: TWT Broadcast Support.
            type: bool
        type: dict
      parentProfile:
        description: Parent profile of 6 GHz radio band.
        type: str
      powerThresholdV1:
        description: Power threshold of 6 GHz radio
          band.
        type: int
      preamblePuncture:
        description: Enable or Disable Preamble Puncturing.
          This Wifi 7 configuration is applicable to
          wireless IOS devices supporting 17.15 and
          higher.
        type: bool
      pscEnforcingEnabled:
        description: PSC Enforcing Enable for 6 GHz
          radio band.
        type: bool
      radioChannels:
        description: DCA channels of 6 GHz radio band
          passed in comma separated format without any
          spaces. Permissible values 1, 5, 9, 13, 17,
          21, 25, 29, 33, 37, 41, 45, 49, 53, 57, 61,
          65, 69, 73, 77, 81, 85, 89, 93, 97, 101, 105,
          109, 113, 117, 121, 125, 129, 133, 137, 141,
          145, 149, 153, 157, 161, 165, 169, 173, 177,
          181, 185, 189, 193, 197, 201, 205, 209, 213,
          217, 221, 225, 229, 233.
        type: str
      rxSopThreshold:
        description: RX-SOP threshold of 6 GHz radio
          band.
        type: str
      spatialReuseProperties:
        description: Wireless Settings Rf Profiles's
          spatialReuseProperties.
        suboptions:
          dot11axNonSrgObssPacketDetect:
            description: Dot11ax Non SRG OBSS PD.
            type: bool
          dot11axNonSrgObssPacketDetectMaxThreshold:
            description: Dot11ax Non SRG OBSS PD Max
              Threshold.
            type: int
          dot11axSrgObssPacketDetect:
            description: Dot11ax SRG OBSS PD.
            type: bool
          dot11axSrgObssPacketDetectMaxThreshold:
            description: Dot11ax SRG OBSS PD Max Threshold.
            type: int
          dot11axSrgObssPacketDetectMinThreshold:
            description: Dot11ax SRG OBSS PD Min Threshold.
            type: int
        type: dict
    type: dict
  radioTypeAProperties:
    description: Wireless Settings Rf Profiles's radioTypeAProperties.
    suboptions:
      channelWidth:
        description: Channel Width.
        type: str
      coverageHoleDetectionProperties:
        description: Wireless Settings Rf Profiles's
          coverageHoleDetectionProperties.
        suboptions:
          chdClientLevel:
            description: Coverage Hole Detection Client
              Level.
            type: int
          chdDataRssiThreshold:
            description: Coverage Hole Detection Data
              Rssi Threshold.
            type: int
          chdExceptionLevel:
            description: Coverage Hole Detection Exception
              Level(%).
            type: int
          chdVoiceRssiThreshold:
            description: Coverage Hole Detection Voice
              Rssi Threshold.
            type: int
        type: dict
      customRxSopThreshold:
        description: RX-SOP threshold custom configuration
          of 5 GHz radio band.
        type: int
      dataRates:
        description: Data rates of 5 GHz radio band
          passed in comma separated format without any
          spaces. Permissible values 6, 9, 12, 18, 24,
          36, 48, 54.
        type: str
      fraPropertiesA:
        description: Wireless Settings Rf Profiles's
          fraPropertiesA.
        suboptions:
          clientAware:
            description: Client Aware of 5 GHz radio
              band.
            type: bool
          clientReset:
            description: Client Reset(%) of 5 GHz radio
              band.
            type: int
          clientSelect:
            description: Client Select(%) of 5 GHz radio
              band.
            type: int
        type: dict
      mandatoryDataRates:
        description: Mandatory data rates of 5 GHz radio
          band passed in comma separated format without
          any spaces and must be a subset of selected
          dataRates with maximum of 2 values. Permissible
          values 6, 9, 12, 18, 24, 36, 48, 54.
        type: str
      maxPowerLevel:
        description: Maximum power level of 5 GHz radio
          band.
        type: int
      maxRadioClients:
        description: Client Limit of 5 GHz radio band.
        type: int
      minPowerLevel:
        description: Minimum power level of 5 GHz radio
          band.
        type: int
      parentProfile:
        description: Parent profile of 5 GHz radio band.
        type: str
      powerThresholdV1:
        description: Power threshold of 5 GHz radio
          band.
        type: int
      preamblePuncture:
        description: Enable or Disable Preamble Puncturing.
          This Wifi 7 configuration is applicable to
          wireless IOS devices supporting 17.15 and
          higher.
        type: bool
      radioChannels:
        description: DCA channels of 5 GHz radio band
          passed in comma separated format without any
          spaces. Permissible values 36, 40, 44, 48,
          52, 56, 60, 64, 100, 104, 108, 112, 116, 120,
          124, 128, 132, 136, 140, 144, 149, 153, 157,
          161, 165, 169, 173.
        type: str
      rxSopThreshold:
        description: RX-SOP threshold of 5 GHz radio
          band.
        type: str
      spatialReuseProperties:
        description: Wireless Settings Rf Profiles's
          spatialReuseProperties.
        suboptions:
          dot11axNonSrgObssPacketDetect:
            description: Dot11ax Non SRG OBSS PD.
            type: bool
          dot11axNonSrgObssPacketDetectMaxThreshold:
            description: Dot11ax Non SRG OBSS PD Max
              Threshold.
            type: int
          dot11axSrgObssPacketDetect:
            description: Dot11ax SRG OBSS PD.
            type: bool
          dot11axSrgObssPacketDetectMaxThreshold:
            description: Dot11ax SRG OBSS PD Max Threshold.
            type: int
          dot11axSrgObssPacketDetectMinThreshold:
            description: Dot11ax SRG OBSS PD Min Threshold.
            type: int
        type: dict
      zeroWaitDfsEnable:
        description: Zero Wait DFS is applicable only
          for IOS-XE based Wireless Controllers running
          17.9.1 and above versions.
        type: bool
    type: dict
  radioTypeBProperties:
    description: Wireless Settings Rf Profiles's radioTypeBProperties.
    suboptions:
      coverageHoleDetectionProperties:
        description: Wireless Settings Rf Profiles's
          coverageHoleDetectionProperties.
        suboptions:
          chdClientLevel:
            description: Coverage Hole Detection Client
              Level.
            type: int
          chdDataRssiThreshold:
            description: Coverage Hole Detection Data
              Rssi Threshold.
            type: int
          chdExceptionLevel:
            description: Coverage Hole Detection Exception
              Level(%).
            type: int
          chdVoiceRssiThreshold:
            description: Coverage Hole Detection Voice
              Rssi Threshold.
            type: int
        type: dict
      customRxSopThreshold:
        description: RX-SOP threshold custom configuration
          of 2.4 GHz radio band.
        type: int
      dataRates:
        description: Data rates of 2.4 GHz radio band
          passed in comma separated format without any
          spaces. Permissible values 1, 2, 5.5, 6, 9,
          11, 12, 18, 24, 36, 48, 54.
        type: str
      mandatoryDataRates:
        description: Mandatory data rates of 2.4 GHz
          radio band passed in comma separated format
          without any spaces and must be a subset of
          selected dataRates with maximum of 2 values.
          Permissible values 1, 2, 5.5, 6, 9, 11, 12,
          18, 24, 36, 48, 54.
        type: str
      maxPowerLevel:
        description: Maximum power level of 2.4 GHz
          radio band.
        type: int
      maxRadioClients:
        description: Client Limit of 2.4 GHz radio band.
        type: int
      minPowerLevel:
        description: Minimum power level of 2.4 GHz
          radio band.
        type: int
      parentProfile:
        description: Parent profile of 2.4 GHz radio
          band.
        type: str
      powerThresholdV1:
        description: Power threshold of 2.4 GHz radio
          band.
        type: int
      radioChannels:
        description: DCA channels of 2.4 GHz radio band
          passed in comma separated format without any
          spaces. Permissible values 1, 2, 3, 4, 5,
          6, 7, 8, 9, 10, 11, 12, 13, 14.
        type: str
      rxSopThreshold:
        description: RX-SOP threshold of 2.4 GHz radio
          band.
        type: str
      spatialReuseProperties:
        description: Wireless Settings Rf Profiles's
          spatialReuseProperties.
        suboptions:
          dot11axNonSrgObssPacketDetect:
            description: Dot11ax Non SRG OBSS PD.
            type: bool
          dot11axNonSrgObssPacketDetectMaxThreshold:
            description: Dot11ax Non SRG OBSS PD Max
              Threshold.
            type: int
          dot11axSrgObssPacketDetect:
            description: Dot11ax SRG OBSS PD.
            type: bool
          dot11axSrgObssPacketDetectMaxThreshold:
            description: Dot11ax SRG OBSS PD Max Threshold.
            type: int
          dot11axSrgObssPacketDetectMinThreshold:
            description: Dot11ax SRG OBSS PD Min Threshold.
            type: int
        type: dict
    type: dict
  rfProfileName:
    description: RF Profile Name.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      CreateRFProfile
    description: Complete reference of the CreateRFProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-rf-profile
  - name: Cisco DNA Center documentation for Wireless
      DeleteRFProfile
    description: Complete reference of the DeleteRFProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-rf-profile
  - name: Cisco DNA Center documentation for Wireless
      UpdateRFProfile
    description: Complete reference of the UpdateRFProfile
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-rf-profile
notes:
  - SDK Method used are
    wireless.Wireless.create_rf_profile,
    wireless.Wireless.delete_rf_profile,
    wireless.Wireless.update_rf_profile,
  - Paths used are
    post /dna/intent/api/v1/wirelessSettings/rfProfiles,
    delete /dna/intent/api/v1/wirelessSettings/rfProfiles/{id},
    put /dna/intent/api/v1/wirelessSettings/rfProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_settings_rf_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    defaultRfProfile: true
    enableRadioType6GHz: true
    enableRadioTypeA: true
    enableRadioTypeB: true
    radioType6GHzProperties:
      broadcastProbeResponseInterval: 0
      coverageHoleDetectionProperties:
        chdClientLevel: 0
        chdDataRssiThreshold: 0
        chdExceptionLevel: 0
        chdVoiceRssiThreshold: 0
      customRxSopThreshold: 0
      dataRates: string
      discoveryFrames6GHz: string
      enableStandardPowerService: true
      fraPropertiesC:
        clientResetCount: 0
        clientUtilizationThreshold: 0
      mandatoryDataRates: string
      maxDbsWidth: 0
      maxPowerLevel: 0
      maxRadioClients: 0
      minDbsWidth: 0
      minPowerLevel: 0
      multiBssidProperties:
        dot11axParameters:
          muMimoDownLink: true
          muMimoUpLink: true
          ofdmaDownLink: true
          ofdmaUpLink: true
        dot11beParameters:
          muMimoDownLink: true
          muMimoUpLink: true
          ofdmaDownLink: true
          ofdmaMultiRu: true
          ofdmaUpLink: true
        targetWakeTime: true
        twtBroadcastSupport: true
      parentProfile: string
      powerThresholdV1: 0
      preamblePuncture: true
      pscEnforcingEnabled: true
      radioChannels: string
      rxSopThreshold: string
      spatialReuseProperties:
        dot11axNonSrgObssPacketDetect: true
        dot11axNonSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetect: true
        dot11axSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetectMinThreshold: 0
    radioTypeAProperties:
      channelWidth: string
      coverageHoleDetectionProperties:
        chdClientLevel: 0
        chdDataRssiThreshold: 0
        chdExceptionLevel: 0
        chdVoiceRssiThreshold: 0
      customRxSopThreshold: 0
      dataRates: string
      fraPropertiesA:
        clientAware: true
        clientReset: 0
        clientSelect: 0
      mandatoryDataRates: string
      maxPowerLevel: 0
      maxRadioClients: 0
      minPowerLevel: 0
      parentProfile: string
      powerThresholdV1: 0
      preamblePuncture: true
      radioChannels: string
      rxSopThreshold: string
      spatialReuseProperties:
        dot11axNonSrgObssPacketDetect: true
        dot11axNonSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetect: true
        dot11axSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetectMinThreshold: 0
      zeroWaitDfsEnable: true
    radioTypeBProperties:
      coverageHoleDetectionProperties:
        chdClientLevel: 0
        chdDataRssiThreshold: 0
        chdExceptionLevel: 0
        chdVoiceRssiThreshold: 0
      customRxSopThreshold: 0
      dataRates: string
      mandatoryDataRates: string
      maxPowerLevel: 0
      maxRadioClients: 0
      minPowerLevel: 0
      parentProfile: string
      powerThresholdV1: 0
      radioChannels: string
      rxSopThreshold: string
      spatialReuseProperties:
        dot11axNonSrgObssPacketDetect: true
        dot11axNonSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetect: true
        dot11axSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetectMinThreshold: 0
    rfProfileName: string
- name: Delete by id
  cisco.dnac.wireless_settings_rf_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.wireless_settings_rf_profiles:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    defaultRfProfile: true
    enableRadioType6GHz: true
    enableRadioTypeA: true
    enableRadioTypeB: true
    id: string
    radioType6GHzProperties:
      broadcastProbeResponseInterval: 0
      coverageHoleDetectionProperties:
        chdClientLevel: 0
        chdDataRssiThreshold: 0
        chdExceptionLevel: 0
        chdVoiceRssiThreshold: 0
      customRxSopThreshold: 0
      dataRates: string
      discoveryFrames6GHz: string
      enableStandardPowerService: true
      fraPropertiesC:
        clientResetCount: 0
        clientUtilizationThreshold: 0
      mandatoryDataRates: string
      maxDbsWidth: 0
      maxPowerLevel: 0
      maxRadioClients: 0
      minDbsWidth: 0
      minPowerLevel: 0
      multiBssidProperties:
        dot11axParameters:
          muMimoDownLink: true
          muMimoUpLink: true
          ofdmaDownLink: true
          ofdmaUpLink: true
        dot11beParameters:
          muMimoDownLink: true
          muMimoUpLink: true
          ofdmaDownLink: true
          ofdmaMultiRu: true
          ofdmaUpLink: true
        targetWakeTime: true
        twtBroadcastSupport: true
      parentProfile: string
      powerThresholdV1: 0
      preamblePuncture: true
      pscEnforcingEnabled: true
      radioChannels: string
      rxSopThreshold: string
      spatialReuseProperties:
        dot11axNonSrgObssPacketDetect: true
        dot11axNonSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetect: true
        dot11axSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetectMinThreshold: 0
    radioTypeAProperties:
      channelWidth: string
      coverageHoleDetectionProperties:
        chdClientLevel: 0
        chdDataRssiThreshold: 0
        chdExceptionLevel: 0
        chdVoiceRssiThreshold: 0
      customRxSopThreshold: 0
      dataRates: string
      fraPropertiesA:
        clientAware: true
        clientReset: 0
        clientSelect: 0
      mandatoryDataRates: string
      maxPowerLevel: 0
      maxRadioClients: 0
      minPowerLevel: 0
      parentProfile: string
      powerThresholdV1: 0
      preamblePuncture: true
      radioChannels: string
      rxSopThreshold: string
      spatialReuseProperties:
        dot11axNonSrgObssPacketDetect: true
        dot11axNonSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetect: true
        dot11axSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetectMinThreshold: 0
      zeroWaitDfsEnable: true
    radioTypeBProperties:
      coverageHoleDetectionProperties:
        chdClientLevel: 0
        chdDataRssiThreshold: 0
        chdExceptionLevel: 0
        chdVoiceRssiThreshold: 0
      customRxSopThreshold: 0
      dataRates: string
      mandatoryDataRates: string
      maxPowerLevel: 0
      maxRadioClients: 0
      minPowerLevel: 0
      parentProfile: string
      powerThresholdV1: 0
      radioChannels: string
      rxSopThreshold: string
      spatialReuseProperties:
        dot11axNonSrgObssPacketDetect: true
        dot11axNonSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetect: true
        dot11axSrgObssPacketDetectMaxThreshold: 0
        dot11axSrgObssPacketDetectMinThreshold: 0
    rfProfileName: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: fabric_site_health_summaries_id_info
short_description: Information module for Fabric Site
  Health Summaries Id
description:
  - Get Fabric Site Health Summaries Id by id.
  - Get Fabric site health summary for a specific fabric
    site by providing the unique fabric site id in the
    url path.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Unique fabric site id.
    type: str
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  attribute:
    description:
      - >
        Attribute query parameter. The list of FabricSite
        health attributes. Please refer to ```fabricSiteAttributes```
        section in the Open API specification document
        mentioned in the description.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view
        being requested. A maximum of 3 views can be
        queried at a time per request. Please refer
        to ```fabricSiteViews``` section in the Open
        API specification document mentioned in the
        description.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for SDA ReadFabricSitesWithHealthSummaryFromId
    description: Complete reference of the ReadFabricSitesWithHealthSummaryFromId
      API.
    link: https://developer.cisco.com/docs/dna-center/#!read-fabric-sites-with-health-summary-from-id
notes:
  - SDK Method used are
    sda.Sda.read_fabric_sites_with_health_summary_from_id,
  - Paths used are
    get /dna/data/api/v1/fabricSiteHealthSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get Fabric Site Health Summaries Id by id
  cisco.dnac.fabric_site_health_summaries_id_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    attribute: string
    view: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "totalDeviceCount": 0,
        "goodHealthPercentage": 0,
        "totalHealthDeviceCount": 0,
        "goodHealthDeviceCount": 0,
        "poorHealthDeviceCount": 0,
        "fairHealthDeviceCount": 0,
        "connectivityGoodHealthPercentage": 0,
        "connectivityTotalHealthDeviceCount": 0,
        "connectivityGoodHealthDeviceCount": 0,
        "connectivityPoorHealthDeviceCount": 0,
        "connectivityFairHealthDeviceCount": 0,
        "infraGoodHealthPercentage": 0,
        "infraTotalHealthDeviceCount": 0,
        "infraGoodHealthDeviceCount": 0,
        "infraFairHealthDeviceCount": 0,
        "infraPoorHealthDeviceCount": 0,
        "controlPlaneGoodHealthPercentage": 0,
        "controlPlaneTotalHealthDeviceCount": 0,
        "controlPlaneGoodHealthDeviceCount": 0,
        "controlPlanePoorHealthDeviceCount": 0,
        "controlPlaneFairHealthDeviceCount": 0,
        "pubsubInfraVnGoodHealthPercentage": 0,
        "pubsubInfraVnTotalHealthDeviceCount": 0,
        "pubsubInfraVnGoodHealthDeviceCount": 0,
        "pubsubInfraVnPoorHealthDeviceCount": 0,
        "pubsubInfraVnFairHealthDeviceCount": 0,
        "bgpEvpnGoodHealthPercentage": 0,
        "bgpEvpnTotalHealthDeviceCount": 0,
        "bgpEvpnGoodHealthDeviceCount": 0,
        "bgpEvpnPoorHealthDeviceCount": 0,
        "bgpEvpnFairHealthDeviceCount": 0,
        "ctsEnvDataDownloadGoodHealthPercentage": 0,
        "ctsEnvDataDownloadTotalHealthDeviceCount": 0,
        "ctsEnvDataDownloadGoodHealthDeviceCount": 0,
        "ctsEnvDataDownloadPoorHealthDeviceCount": 0,
        "ctsEnvDataDownloadFairHealthDeviceCount": 0,
        "aaaStatusGoodHealthPercentage": 0,
        "aaaStatusTotalHealthDeviceCount": 0,
        "aaaStatusGoodHealthDeviceCount": 0,
        "aaaStatusPoorHealthDeviceCount": 0,
        "aaaStatusFairHealthDeviceCount": 0,
        "portChannelGoodHealthPercentage": 0,
        "portChannelTotalHealthDeviceCount": 0,
        "portChannelGoodHealthDeviceCount": 0,
        "portChannelPoorHealthDeviceCount": 0,
        "portChannelFairHealthDeviceCount": 0,
        "peerScoreGoodHealthPercentage": 0,
        "peerScoreTotalHealthDeviceCount": 0,
        "peerScoreGoodHealthDeviceCount": 0,
        "peerScorePoorHealthDeviceCount": 0,
        "peerScoreFairHealthDeviceCount": 0,
        "lispSessionGoodHealthPercentage": 0,
        "lispSessionTotalHealthDeviceCount": 0,
        "lispSessionGoodHealthDeviceCount": 0,
        "lispSessionPoorHealthDeviceCount": 0,
        "lispSessionFairHealthDeviceCount": 0,
        "borderToControlPlaneGoodHealthPercentage": 0,
        "borderToControlPlaneTotalHealthDeviceCount": 0,
        "borderToControlPlaneGoodHealthDeviceCount": 0,
        "borderToControlPlanePoorHealthDeviceCount": 0,
        "borderToControlPlaneFairHealthDeviceCount": 0,
        "bgpBgpSiteGoodHealthPercentage": 0,
        "bgpBgpSiteTotalHealthDeviceCount": 0,
        "bgpBgpSiteGoodHealthDeviceCount": 0,
        "bgpBgpSitePoorHealthDeviceCount": 0,
        "bgpBgpSiteFairHealthDeviceCount": 0,
        "bgpPubsubSiteGoodHealthPercentage": 0,
        "bgpPubsubSiteTotalHealthDeviceCount": 0,
        "bgpPubsubSiteGoodHealthDeviceCount": 0,
        "bgpPubsubSitePoorHealthDeviceCount": 0,
        "bgpPubsubSiteFairHealthDeviceCount": 0,
        "bgpPeerInfraVnScoreGoodHealthPercentage": 0,
        "bgpPeerInfraVnTotalHealthDeviceCount": 0,
        "bgpPeerInfraVnGoodHealthDeviceCount": 0,
        "bgpPeerInfraVnPoorHealthDeviceCount": 0,
        "bgpPeerInfraVnFairHealthDeviceCount": 0,
        "associatedL2VnCount": 0,
        "associatedL3VnCount": 0,
        "networkProtocol": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_profile_assignments_info
short_description: Information module for Sites Profile
  Assignments
description:
  - Get all Sites Profile Assignments. - > Retrieves
    the list of profiles that the given site has been
    assigned. These profiles may either be directly
    assigned to this site, or were assigned to a parent
    site and have been inherited.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - SiteId path parameter. The `id` of the site,
        retrievable from `/dna/intent/api/v1/sites`.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: float
  limit:
    description:
      - Limit query parameter. The number of records
        to show for this page;The minimum is 1, and
        the maximum is 500.
    type: float
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Site Design
      RetrievesTheListOfNetworkProfilesThatTheGivenSiteHasBeenAssigned
    description: Complete reference of the RetrievesTheListOfNetworkProfilesThatTheGivenSiteHasBeenAssigned
      API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-network-profiles-that-the-given-site-has-been-assigned
notes:
  - SDK Method used are
    site_design.SiteDesign.retrieves_the_list_of_network_profiles_that_the_given_site_has_been_assigned,
  - Paths used are
    get /dna/intent/api/v1/sites/{siteId}/profileAssignments,
"""

EXAMPLES = r"""
---
- name: Get all Sites Profile Assignments
  cisco.dnac.sites_profile_assignments_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    offset: 0
    limit: 0
    siteId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: images_addon_images_count_info
short_description: Information module for Images Addon
  Images Count
description:
  - Get all Images Addon Images Count. - > Count of
    add-on images available for the given software image
    identifier, `id` can be obtained from the response
    of API /dna/intent/api/v1/images?hasAddonImages=true
    .
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Software image identifier.
        Check API `/dna/intent/api/v1/images` for id
        from response.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) ReturnsCountOfAddOnImages
    description: Complete reference of the ReturnsCountOfAddOnImages
      API.
    link: https://developer.cisco.com/docs/dna-center/#!returns-count-of-add-on-images
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.returns_count_of_add_on_images,
  - Paths used are
    get /dna/intent/api/v1/images/{id}/addonImages/count,
"""

EXAMPLES = r"""
---
- name: Get all Images Addon Images Count
  cisco.dnac.images_addon_images_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sda_fabrics_vlan_to_ssids_fabric_id_count_info
short_description: Information module for Sda Fabrics
  Vlan To Ssids Fabric Id Count
description:
  - Get all Sda Fabrics Vlan To Ssids Fabric Id Count.
    - > Returns the count of VLANs mapped to SSIDs in
    a Fabric Site. The 'fabricId' represents the Fabric
    ID of a particular Fabric Site.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  fabricId:
    description:
      - FabricId path parameter. The 'fabricId' represents
        the Fabric ID of a particular Fabric Site.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Fabric
      Wireless ReturnsTheCountOfVLANsMappedToSSIDsInAFabricSite
    description: Complete reference of the ReturnsTheCountOfVLANsMappedToSSIDsInAFabricSite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!returns-the-count-of-vla-ns-mapped-to-ssi-ds-in-a-fabric-site
notes:
  - SDK Method used are
    fabric_wireless.FabricWireless.returns_the_count_of_vlans_mapped_to_ssids_in_a_fabric_site,
  - Paths used are
    get /dna/intent/api/v1/sda/fabrics/{fabricId}/vlanToSsids/count,
"""

EXAMPLES = r"""
---
- name: Get all Sda Fabrics Vlan To Ssids Fabric Id
    Count
  cisco.dnac.sda_fabrics_vlan_to_ssids_fabric_id_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    fabricId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_wise_images_summary_info
short_description: Information module for Site Wise
  Images Summary
description:
  - Get all Site Wise Images Summary. - > Returns aggregate
    counts of network device product names, golden and
    non-golden tagged products, imported images, golden
    images tagged, and advisor for a specific site provide,
    the default value of `siteId` is set to global.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  siteId:
    description:
      - >
        SiteId query parameter. Site identifier to get
        the aggreagte counts products under the site.
        The default value is global site id. See https
        //developer.cisco.com/docs/dna-center(#!get-site)
        for `siteId`.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Software
      Image Management (SWIM) ReturnsTheImageSummaryForTheGivenSite
    description: Complete reference of the ReturnsTheImageSummaryForTheGivenSite
      API.
    link: https://developer.cisco.com/docs/dna-center/#!returns-the-image-summary-for-the-given-site
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.returns_the_image_summary_for_the_given_site,
  - Paths used are
    get /dna/intent/api/v1/siteWiseImagesSummary,
"""

EXAMPLES = r"""
---
- name: Get all Site Wise Images Summary
  cisco.dnac.site_wise_images_summary_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    siteId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "importedImageCount": 0,
        "installedImageCount": 0,
        "goldenImageCount": 0,
        "nonGoldenImageCount": 0,
        "installedImageAdvisorCount": 0,
        "productCount": 0,
        "productsWithGoldenCount": 0,
        "productsWithoutGoldenCount": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_issues_count_info
short_description: Information module for Assurance
  Issues Count
description:
  - Get all Assurance Issues Count. - > Returns the
    total number issues for given set of filters. If
    there is no start and/or end time, then end time
    will be defaulted to current time and start time
    will be defaulted to 24-hours ago from end time.
    Https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-
    IssuesList-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which
        API queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive. If `startTime` is not provided,
        API will default to current time.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API
        queries the data set related to the resource.
        It must be specified in UNIX epochtime in milliseconds.
        Value is inclusive.
    type: float
  isGlobal:
    description:
      - >
        IsGlobal query parameter. Global issues are
        those issues which impacts across many devices,
        sites. They are also displayed on Issue Dashboard
        in Catalyst Center UI. Non-Global issues are
        displayed only on Client 360 or Device 360 pages.
        If this flag is 'true', only global issues are
        returned. If it if 'false', all issues are returned.
    type: bool
  priority:
    description:
      - >
        Priority query parameter. Priority of the issue.
        Supports single priority and multiple priorities
        Examples priority=P1 (single priority requested)
        priority=P1&priority=P2&priority=P3 (multiple
        priorities requested).
    type: str
  severity:
    description:
      - >
        Severity query parameter. Severity of the issue.
        Supports single severity and multiple severities.
        Examples severity=high (single severity requested)
        severity=high&severity=medium (multiple severities
        requested).
    type: str
  status:
    description:
      - >
        Status query parameter. Status of the issue.
        Supports single status and multiple statuses.
        Examples status=active (single status requested)
        status=active&status=resolved (multiple statuses
        requested).
    type: str
  entityType:
    description:
      - >
        EntityType query parameter. Entity type of the
        issue. Supports single entity type and multiple
        entity types. Examples entityType=networkDevice
        (single entity type requested) entityType=network
        device&entityType=client (multiple entity types
        requested).
    type: str
  category:
    description:
      - >
        Category query parameter. Categories of the
        issue. Supports single category and multiple
        categories. Examples category=availability (single
        status requested) category=availability&category=onboarding
        (multiple categories requested).
    type: str
  deviceType:
    description:
      - >
        DeviceType query parameter. Device Type of the
        device to which this issue belongs to. Supports
        single device type and multiple device types.
        Examples deviceType=wireless controller (single
        device type requested) deviceType=wireless controller&deviceType=core
        (multiple device types requested).
    type: str
  name:
    description:
      - >
        Name query parameter. The name of the issue
        Examples name=ap_down (single issue name requested)
        name=ap_down&name=wlc_monitor (multiple issue
        names requested) Issue names can be retrieved
        using the API - /data/api/v1/assuranceIssueConfigurations.
    type: str
  issueId:
    description:
      - >
        IssueId query parameter. UUID of the issue Examples
        issueId=e52aecfe-b142-4287-a587-11a16ba6dd26
        (single issue id requested) issueId=e52aecfe-b142-4287-a587-11a16ba6dd26&issueId=864d0421-02c0-43a6-9c52-81cad45f66d8
        (multiple issue ids requested).
    type: str
  entityId:
    description:
      - >
        EntityId query parameter. Id of the entity for
        which this issue belongs to. For example, it
        could be mac address of AP or UUID of Sensor
        example 68 ca e4 79 3f 20 4de02167-901b-43cf-8822-cffd3caa286f
        Examples entityId=68 ca e4 79 3f 20 (single
        entity id requested) entityId=68 ca e4 79 3f
        20&entityId=864d0421-02c0-43a6-9c52-81cad45f66d8
        (multiple entity ids requested).
    type: str
  updatedBy:
    description:
      - >
        UpdatedBy query parameter. The user who last
        updated this issue. Examples updatedBy=admin
        (single updatedBy requested) updatedBy=admin&updatedBy=john
        (multiple updatedBy requested).
    type: str
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical
        breakdown of the site tree starting from Global
        site name and ending with the specific site
        name. The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`)
        This field supports wildcard asterisk (*) character
        search support. E.g. */San*, */San, /San* Examples
        `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple
        siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy
        breakdown of the site tree in id form starting
        from Global site UUID and ending with the specific
        site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`)
        This field supports wildcard asterisk (*) character
        search support. E.g. `*uuid*, *uuid, uuid* Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
        `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteName:
    description:
      - >
        SiteName query parameter. The name of the site.
        (Ex. `FloorName`) This field supports wildcard
        asterisk (*) character search support. E.g.
        *San*, *San, San* Examples `?siteName=building1`
        (single siteName requested) `?siteName=building1&siteName=building2&siteName=building3`
        (multiple siteNames requested).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site.
        (Ex. `flooruuid`) This field supports wildcard
        asterisk (*) character search support. E.g.*flooruuid*,
        *flooruuid, flooruuid* Examples `?siteId=id1`
        (single id requested) `?siteId=id1&siteId=id2&siteId=id3`
        (multiple ids requested).
    type: str
  fabricSiteId:
    description:
      - >
        FabricSiteId query parameter. The UUID of the
        fabric site. (Ex. "flooruuid") Examples fabricSiteId=e52aecfe-b142-4287-a587-11a16ba6dd26
        (single id requested) fabricSiteId=e52aecfe-b142-4287-a587-11a16ba6dd26,864d0421-02c0-43a6-9c52-81cad45f66d8
        (multiple ids requested).
    type: str
  fabricVnName:
    description:
      - >
        FabricVnName query parameter. The name of the
        fabric virtual network Examples fabricVnName=name1
        (single fabric virtual network name requested)
        fabricVnName=name1&fabricVnName=name2&fabricVnName=name3
        (multiple fabric virtual network names requested).
    type: str
  fabricTransitSiteId:
    description:
      - >
        FabricTransitSiteId query parameter. The UUID
        of the fabric transit site. (Ex. "flooruuid")
        Examples fabricTransitSiteId=e52aecfe-b142-4287-a587-11a16ba6dd26
        (single id requested) fabricTransitSiteId=e52ae
        cfe-b142-4287-a587-11a16ba6dd26&fabricTransitSiteId=864d0421-02c0-43a6-9c52-81cad45f66d8
        (multiple ids requested).
    type: str
  networkDeviceId:
    description:
      - >
        NetworkDeviceId query parameter. The list of
        Network Device Uuids. (Ex. `6bef213c-19ca-4170-8375-b694e251101c`)
        Examples `networkDeviceId=6bef213c-19ca-4170-8375-b694e251101c`
        (single networkDeviceId requested) `networkDeviceId=6bef213c-19ca-4170-8375-
        b694e251101c&networkDeviceId=32219612-819e-4b5e-a96b-cf22aca13dd9&networkDeviceId=2541e9a7-b80d-4955-
        8aa2-79b233318ba0` (multiple networkDeviceIds
        with & separator).
    type: str
  networkDeviceIpAddress:
    description:
      - >
        NetworkDeviceIpAddress query parameter. The
        list of Network Device management IP Address.
        (Ex. `121.1.1.10`) This field supports wildcard
        (`*`) character-based search. Ex `*1.1*` or
        `1.1*` or `*1.1` Examples `networkDeviceIpAddress=121.1.1.10`
        `networkDeviceIpAddress=121.1.1.10&networkDeviceIpAddress=1
        72.20.1.10&networkDeviceIpAddress=10.10.20.10`
        (multiple networkDevice IP Address with & separator).
    type: str
  macAddress:
    description:
      - >
        MacAddress query parameter. The macAddress of
        the network device or client This field supports
        wildcard (`*`) character-based search. Ex `*AB
        AB AB*` or `AB AB AB*` or `*AB AB AB` Examples
        `macAddress=AB AB AB CD CD CD` (single macAddress
        requested) `macAddress=AB AB AB CD CD DC&macAddress=AB
        AB AB CD CD FE` (multiple macAddress requested).
    type: str
  aiDriven:
    description:
      - AiDriven query parameter. Flag whether the issue
        is AI driven issue.
    type: bool
  fabricDriven:
    description:
      - FabricDriven query parameter. Flag whether the
        issue is related to a Fabric site, a virtual
        network or a transit.
    type: bool
  fabricSiteDriven:
    description:
      - FabricSiteDriven query parameter. Flag whether
        the issue is Fabric site driven issue.
    type: bool
  fabricVnDriven:
    description:
      - FabricVnDriven query parameter. Flag whether
        the issue is Fabric Virtual Network driven issue.
    type: bool
  fabricTransitDriven:
    description:
      - FabricTransitDriven query parameter. Flag whether
        the issue is Fabric Transit driven issue.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Issues
      GetTheTotalNumberOfIssuesForGivenSetOfFiltersKnowYourNetwork
    description: Complete reference of the GetTheTotalNumberOfIssuesForGivenSetOfFiltersKnowYourNetwork
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-the-total-number-of-issues-for-given-set-of-filters-know-your-network
notes:
  - SDK Method used are
    issues.Issues.get_the_total_number_of_issues_for_given_set_of_filters_know_your_network,
  - Paths used are
    get /dna/data/api/v1/assuranceIssues/count,
"""

EXAMPLES = r"""
---
- name: Get all Assurance Issues Count
  cisco.dnac.assurance_issues_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    isGlobal: true
    priority: string
    severity: string
    status: string
    entityType: string
    category: string
    deviceType: string
    name: string
    issueId: string
    entityId: string
    updatedBy: string
    siteHierarchy: string
    siteHierarchyId: string
    siteName: string
    siteId: string
    fabricSiteId: string
    fabricVnName: string
    fabricTransitSiteId: string
    networkDeviceId: string
    networkDeviceIpAddress: string
    macAddress: string
    aiDriven: true
    fabricDriven: true
    fabricSiteDriven: true
    fabricVnDriven: true
    fabricTransitDriven: true
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_wireless_settings_ssids
short_description: Resource module for Sites Wireless
  Settings Ssids
description:
  - Manage operations create, update and delete of the
    resource Sites Wireless Settings Ssids.
  - This API allows the user to create an SSID Service
    Set Identifier at the Global site. - > This API
    allows the user to delete an SSID Service Set Identifier
    at the global level , if the SSID is not mapped
    to any Wireless Profile, Or remove override from
    given site Id .
  - This API allows the user to update an SSID Service
    Set Identifier at the given site.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  aaaOverride:
    description: Activate the AAA Override feature when
      set to true.
    type: bool
  acctServers:
    description: List of Accounting server IpAddresses.
    elements: str
    type: list
  aclName:
    description: Pre-Auth Access Control List (ACL)
      Name.
    type: str
  authServer:
    description: For Guest SSIDs ('wlanType' is 'Guest'
      and 'l3AuthType' is 'web_auth'), the Authentication
      Server('authServer') is mandatory. Otherwise,
      it defaults to 'auth_external'.
    type: str
  authServers:
    description: List of Authentication/Authorization
      server IpAddresses.
    elements: str
    type: list
  authType:
    description: L2 Authentication Type (If authType
      is not open , then atleast one RSN Cipher Suite
      and corresponding valid AKM must be enabled).
      Default is L2 Authentication Type if exists else
      None.
    type: str
  basicServiceSetClientIdleTimeout:
    description: This refers to the duration of inactivity,
      measured in seconds, before a client connected
      to the Basic Service Set is considered idle and
      timed out. Default is Basic ServiceSet ClientIdle
      Timeout if exists else 300. If it needs to be
      disabled , pass 0 as its value else valid range
      is 15 to 100000.
    type: int
  basicServiceSetMaxIdleEnable:
    description: Activate the maximum idle feature for
      the Basic Service Set.
    type: bool
  cckmTsfTolerance:
    description: He default value is the Cckm Timestamp
      Tolerance (in milliseconds, if specified); otherwise,
      it is 0.
    type: int
  clientExclusionEnable:
    description: Activate the feature that allows for
      the exclusion of clients.
    type: bool
  clientExclusionTimeout:
    description: This refers to the length of time,
      in seconds, a client is excluded or blocked from
      accessing the network after a specified number
      of unsuccessful attempts. Default is Client Exclusion
      Timeout if exists else 180.
    type: int
  clientRateLimit:
    description: This pertains to the maximum data transfer
      rate, specified in bits per second, that a client
      is permitted to achieve. It should be in mutliples
      of 500. Default is Client Rate Limit if exists
      else 0.
    type: int
  coverageHoleDetectionEnable:
    description: Activate Coverage Hole Detection feature
      when set to true.
    type: bool
  directedMulticastServiceEnable:
    description: The Directed Multicast Service feature
      becomes operational when it is set to true.
    type: bool
  egressQos:
    description: Egress QOS.
    type: str
  externalAuthIpAddress:
    description: External WebAuth URL (Mandatory for
      Guest SSIDs with wlanType = Guest, l3AuthType
      = web_auth and authServer = auth_external).
    type: str
  fastTransition:
    description: Fast Transition.
    type: str
  fastTransitionOverTheDistributedSystemEnable:
    description: Enable Fast Transition over the Distributed
      System when set to true.
    type: bool
  ghz24Policy:
    description: 2.4 Ghz Band Policy value. Allowed
      only when 2.4 Radio Band is enabled in ssidRadioType.
    type: str
  ghz6PolicyClientSteering:
    description: True if 6 GHz Policy Client Steering
      is enabled, else False.
    type: bool
  id:
    description: Id path parameter. SSID ID.
    type: str
  ingressQos:
    description: Ingress QOS.
    type: str
  isApBeaconProtectionEnabled:
    description: When set to true, the Access Point
      (AP) Beacon Protection feature is activated, enhancing
      the security of the network.
    type: bool
  isAuthKey8021x:
    description: When set to true, the 802.1X authentication
      key is in use.
    type: bool
  isAuthKey8021xPlusFT:
    description: When set to true, the 802.1X-Plus-FT
      authentication key is in use.
    type: bool
  isAuthKey8021x_SHA256:
    description: When set to true, the feature that
      enables 802.1X authentication using the SHA256
      algorithm is turned on.
    type: bool
  isAuthKeyEasyPSK:
    description: When set to true, the feature that
      enables the use of Easy Pre-shared Key (PSK) authentication
      is activated.
    type: bool
  isAuthKeyOWE:
    description: When set to true, the Opportunistic
      Wireless Encryption (OWE) authentication key feature
      is turned on.
    type: bool
  isAuthKeyPSK:
    description: When set to true, the Pre-shared Key
      (PSK) authentication feature is enabled.
    type: bool
  isAuthKeyPSKPlusFT:
    description: When set to true, the feature that
      enables the combination of Pre-shared Key (PSK)
      and Fast Transition (FT) authentication keys is
      activated.
    type: bool
  isAuthKeyPSKSHA256:
    description: The feature that allows the use of
      Pre-shared Key (PSK) authentication with the SHA256
      algorithm is enabled when it is set to true.
    type: bool
  isAuthKeySae:
    description: When set to true, the feature enabling
      the Simultaneous Authentication of Equals (SAE)
      authentication key is activated.
    type: bool
  isAuthKeySaeExt:
    description: When set to true, the Simultaneous
      Authentication of Equals (SAE) Extended Authentication
      key feature is turned on.
    type: bool
  isAuthKeySaeExtPlusFT:
    description: When set to true, the Simultaneous
      Authentication of Equals (SAE) combined with Fast
      Transition (FT) Authentication Key feature is
      enabled.
    type: bool
  isAuthKeySaePlusFT:
    description: Activating this setting by switching
      it to true turns on the authentication key feature
      that supports both Simultaneous Authentication
      of Equals (SAE) and Fast Transition (FT).
    type: bool
  isAuthKeySuiteB1921x:
    description: When set to true, the SuiteB192-1x
      authentication key feature is enabled.
    type: bool
  isAuthKeySuiteB1x:
    description: When activated by setting it to true,
      the SuiteB-1x authentication key feature is engaged.
    type: bool
  isBroadcastSSID:
    description: When activated by setting it to true,
      the Broadcast SSID feature will make the SSID
      publicly visible to wireless devices searching
      for available networks.
    type: bool
  isCckmEnabled:
    description: True if CCKM is enabled, else False.
    type: bool
  isEnabled:
    description: Set SSID's admin status as 'Enabled'
      when set to true.
    type: bool
  isFastLaneEnabled:
    description: True if FastLane is enabled, else False.
    type: bool
  isHex:
    description: True if passphrase is in Hex format,
      else False.
    type: bool
  isMacFilteringEnabled:
    description: When set to true, MAC Filtering will
      be activated, allowing control over network access
      based on the MAC address of the device.
    type: bool
  isPosturingEnabled:
    description: Applicable only for Enterprise SSIDs.
      When set to True, Posturing will enabled. Required
      to be set to True if ACL needs to be mapped for
      Enterprise SSID.
    type: bool
  isRadiusProfilingEnabled:
    description: '''true'' if Radius profiling needs
      to be enabled, defaults to ''false'' if not specified.
      At least one AAA/PSN server is required to enable
      Radius Profiling.'
    type: bool
  isRandomMacFilterEnabled:
    description: Deny clients using randomized MAC addresses
      when set to true.
    type: bool
  l3AuthType:
    description: L3 Authentication Type. When *wlanType*
      is *Enterprise*, *l3AuthType* is optional and
      defaults to *open* if not specified. If *wlanType*
      is *Guest* then *l3AuthType* is mandatory.
    type: str
  managementFrameProtectionClientprotection:
    description: Default is Management Frame Protection
      Client if exists else Optional.
    type: str
  multiPSKSettings:
    description: Sites Wireless Settings Ssids's multiPSKSettings.
    elements: dict
    suboptions:
      passphrase:
        description: Passphrase needs to be between
          8 and 63 characters for ASCII type. HEX passphrase
          needs to be 64 characters.
        type: str
      passphraseType:
        description: Passphrase Type(default ASCII).
        type: str
      priority:
        description: Priority.
        type: int
    type: list
  nasOptions:
    description: Pre-Defined NAS Options AP ETH Mac
      Address, AP IP address, AP Location , AP MAC Address,
      AP Name, AP Policy Tag, AP Site Tag, SSID, System
      IP Address, System MAC Address, System Name.
    elements: str
    type: list
  neighborListEnable:
    description: The Neighbor List feature is enabled
      when it is set to true.
    type: bool
  openSsid:
    description: Open SSID which is already created
      in the design and not associated to any other
      OPEN-SECURED SSID.
    type: str
  passphrase:
    description: Passphrase (Only applicable for SSID
      with PERSONAL security level). Passphrase needs
      to be between 8 and 63 characters for ASCII type.
      HEX passphrase needs to be 64 characters.
    type: str
  policyProfileName:
    description: "Policy Profile Name. If 'policyProfileName'
      is not provided, the value of 'profileName' will
      be assigned to it. If 'profileName' is also not
      provided, an autogenerated name will be used.
      Autogenerated name is generated by appending 'ssid'
      field's value with '_profile' (Example If 'ssid'
      = 'ExampleSsid', then autogenerated name will
      be 'ExampleSsid_profile')."
    type: str
  profileName:
    description: WLAN Profile Name, if not passed autogenerated
      profile name will be assigned.
    type: str
  protectedManagementFrame:
    description: (REQUIRED is applicable for authType
      WPA3_PERSONAL, WPA3_ENTERPRISE, OPEN_SECURED)
      and (OPTIONAL/REQUIRED is applicable for authType
      WPA2_WPA3_PERSONAL and WPA2_WPA3_ENTERPRISE).
    type: str
  removeOverrideInHierarchy:
    description: RemoveOverrideInHierarchy query parameter.
      Remove override in hierarchy. Refer Feature tab
      for details.
    type: bool
  rsnCipherSuiteCcmp128:
    description: When set to true, the Robust Security
      Network (RSN) Cipher Suite CCMP128 encryption
      protocol is activated.
    type: bool
  rsnCipherSuiteCcmp256:
    description: When set to true, the Robust Security
      Network (RSN) Cipher Suite CCMP256 encryption
      protocol is activated.
    type: bool
  rsnCipherSuiteGcmp128:
    description: When set to true, the Robust Security
      Network (RSN) Cipher Suite GCMP128 encryption
      protocol is activated.
    type: bool
  rsnCipherSuiteGcmp256:
    description: When set to true, the Robust Security
      Network (RSN) Cipher Suite GCMP256 encryption
      protocol is activated.
    type: bool
  sessionTimeOut:
    description: This denotes the allotted time span,
      expressed in seconds, before a session is automatically
      terminated due to inactivity. Default sessionTimeOut
      is 1800.
    type: int
  sessionTimeOutEnable:
    description: Turn on the feature that imposes a
      time limit on user sessions.
    type: bool
  siteId:
    description: SiteId path parameter. Site UUID of
      Global site.
    type: str
  sleepingClientEnable:
    description: When set to true, this will activate
      the timeout settings that apply to clients in
      sleep mode.
    type: bool
  sleepingClientTimeout:
    description: This refers to the amount of time,
      measured in minutes, before a sleeping (inactive)
      client is timed out of the network. Default is
      Sleeping Client Timeout if exists else 720.
    type: int
  ssid:
    description: Name of the SSID.
    type: str
  ssidRadioType:
    description: Radio Policy Enum (default Triple band
      operation(2.4GHz, 5GHz and 6GHz)).
    type: str
  webPassthrough:
    description: When set to true, the Web-Passthrough
      feature will be activated for the Guest SSID,
      allowing guests to bypass certain login requirements.
    type: bool
  wlanBandSelectEnable:
    description: Band select is allowed only when band
      options selected contains at least 2.4 GHz and
      5 GHz band else false.
    type: bool
  wlanType:
    description: Wlan Type.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      CreateSSID
    description: Complete reference of the CreateSSID
      API.
    link: https://developer.cisco.com/docs/dna-center/#!create-ssid
  - name: Cisco DNA Center documentation for Wireless
      DeleteSSID
    description: Complete reference of the DeleteSSID
      API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-ssid
  - name: Cisco DNA Center documentation for Wireless
      UpdateSSID
    description: Complete reference of the UpdateSSID
      API.
    link: https://developer.cisco.com/docs/dna-center/#!update-ssid
notes:
  - SDK Method used are
    wireless.Wireless.create_ssid,
    wireless.Wireless.delete_ssid,
    wireless.Wireless.update_ssid,
  - Paths used are
    post /dna/intent/api/v1/sites/{siteId}/wirelessSettings/ssids,
    delete /dna/intent/api/v1/sites/{siteId}/wirelessSettings/ssids/{id},
    put /dna/intent/api/v1/sites/{siteId}/wirelessSettings/ssids/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.sites_wireless_settings_ssids:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    aaaOverride: true
    acctServers:
      - string
    aclName: string
    authServer: string
    authServers:
      - string
    authType: string
    basicServiceSetClientIdleTimeout: 0
    basicServiceSetMaxIdleEnable: true
    cckmTsfTolerance: 0
    clientExclusionEnable: true
    clientExclusionTimeout: 0
    clientRateLimit: 0
    coverageHoleDetectionEnable: true
    directedMulticastServiceEnable: true
    egressQos: string
    externalAuthIpAddress: string
    fastTransition: string
    fastTransitionOverTheDistributedSystemEnable: true
    ghz24Policy: string
    ghz6PolicyClientSteering: true
    ingressQos: string
    isApBeaconProtectionEnabled: true
    isAuthKey8021x: true
    isAuthKey8021xPlusFT: true
    isAuthKey8021x_SHA256: true
    isAuthKeyEasyPSK: true
    isAuthKeyOWE: true
    isAuthKeyPSK: true
    isAuthKeyPSKPlusFT: true
    isAuthKeyPSKSHA256: true
    isAuthKeySae: true
    isAuthKeySaeExt: true
    isAuthKeySaeExtPlusFT: true
    isAuthKeySaePlusFT: true
    isAuthKeySuiteB1921x: true
    isAuthKeySuiteB1x: true
    isBroadcastSSID: true
    isCckmEnabled: true
    isEnabled: true
    isFastLaneEnabled: true
    isHex: true
    isMacFilteringEnabled: true
    isPosturingEnabled: true
    isRadiusProfilingEnabled: true
    isRandomMacFilterEnabled: true
    l3AuthType: string
    managementFrameProtectionClientprotection: string
    multiPSKSettings:
      - passphrase: string
        passphraseType: string
        priority: 0
    nasOptions:
      - string
    neighborListEnable: true
    openSsid: string
    passphrase: string
    policyProfileName: string
    profileName: string
    protectedManagementFrame: string
    rsnCipherSuiteCcmp128: true
    rsnCipherSuiteCcmp256: true
    rsnCipherSuiteGcmp128: true
    rsnCipherSuiteGcmp256: true
    sessionTimeOut: 0
    sessionTimeOutEnable: true
    siteId: string
    sleepingClientEnable: true
    sleepingClientTimeout: 0
    ssid: string
    ssidRadioType: string
    webPassthrough: true
    wlanBandSelectEnable: true
    wlanType: string
- name: Update by id
  cisco.dnac.sites_wireless_settings_ssids:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    aaaOverride: true
    acctServers:
      - string
    aclName: string
    authServer: string
    authServers:
      - string
    authType: string
    basicServiceSetClientIdleTimeout: 0
    basicServiceSetMaxIdleEnable: true
    cckmTsfTolerance: 0
    clientExclusionEnable: true
    clientExclusionTimeout: 0
    clientRateLimit: 0
    coverageHoleDetectionEnable: true
    directedMulticastServiceEnable: true
    egressQos: string
    externalAuthIpAddress: string
    fastTransition: string
    fastTransitionOverTheDistributedSystemEnable: true
    ghz24Policy: string
    ghz6PolicyClientSteering: true
    id: string
    ingressQos: string
    isApBeaconProtectionEnabled: true
    isAuthKey8021x: true
    isAuthKey8021xPlusFT: true
    isAuthKey8021x_SHA256: true
    isAuthKeyEasyPSK: true
    isAuthKeyOWE: true
    isAuthKeyPSK: true
    isAuthKeyPSKPlusFT: true
    isAuthKeyPSKSHA256: true
    isAuthKeySae: true
    isAuthKeySaeExt: true
    isAuthKeySaeExtPlusFT: true
    isAuthKeySaePlusFT: true
    isAuthKeySuiteB1921x: true
    isAuthKeySuiteB1x: true
    isBroadcastSSID: true
    isCckmEnabled: true
    isEnabled: true
    isFastLaneEnabled: true
    isHex: true
    isMacFilteringEnabled: true
    isPosturingEnabled: true
    isRadiusProfilingEnabled: true
    isRandomMacFilterEnabled: true
    l3AuthType: string
    managementFrameProtectionClientprotection: string
    multiPSKSettings:
      - passphrase: string
        passphraseType: string
        priority: 0
    nasOptions:
      - string
    neighborListEnable: true
    openSsid: string
    passphrase: string
    policyProfileName: string
    profileName: string
    protectedManagementFrame: string
    rsnCipherSuiteCcmp128: true
    rsnCipherSuiteCcmp256: true
    rsnCipherSuiteGcmp128: true
    rsnCipherSuiteGcmp256: true
    sessionTimeOut: 0
    sessionTimeOutEnable: true
    siteId: string
    sleepingClientEnable: true
    sleepingClientTimeout: 0
    ssid: string
    ssidRadioType: string
    webPassthrough: true
    wlanBandSelectEnable: true
    wlanType: string
- name: Delete by id
  cisco.dnac.sites_wireless_settings_ssids:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
    removeOverrideInHierarchy: true
    siteId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: networks_alerts_history_info
short_description: Information module for networks _alerts _history
description:
  - Get all networks _alerts _history.
  - Return the alert history for this network.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
  - cisco.meraki.module_info_pagination
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
      - NetworkId path parameter. Network ID.
    type: str
  perPage:
    description:
      - PerPage query parameter. The number of entries per page returned. Acceptable range is 3 - 1000. Default is 100.
    type: int
  startingAfter:
    description:
      - >
        StartingAfter query parameter. A token used by the server to indicate the start of the page. Often this is a timestamp or an ID but it
        is not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page
        in the HTTP Link header should define it.
    type: str
  endingBefore:
    description:
      - >
        EndingBefore query parameter. A token used by the server to indicate the end of the page. Often this is a timestamp or an ID but it is
        not limited to those. This parameter should not be defined by client applications. The link for the first, last, prev, or next page in
        the HTTP Link header should define it.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for networks getNetworkAlertsHistory
    description: Complete reference of the getNetworkAlertsHistory API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-network-alerts-history
notes:
  - SDK Method used are
    networks.Networks.get_network_alerts_history,
  - Paths used are
    get /networks/{networkId}/alerts/history,
"""

EXAMPLES = r"""
- name: Get all networks _alerts _history
  cisco.meraki.networks_alerts_history_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    perPage: 0
    startingAfter: string
    endingBefore: string
    networkId: string
    total_pages: -1
    direction: next
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "alertData": {},
        "alertType": "string",
        "alertTypeId": "string",
        "destinations": {
          "email": {
            "sentAt": "string"
          },
          "push": {
            "sentAt": "string"
          },
          "sms": {
            "sentAt": "string"
          },
          "webhook": {
            "sentAt": "string"
          }
        },
        "device": {
          "serial": "string"
        },
        "occurredAt": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: event_subscription_details_rest_info
short_description: Information module for Event Subscription
  Details Rest
description:
  - Get all Event Subscription Details Rest.
  - Gets the list of subscription details for specified
    connectorType.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  name:
    description:
      - Name query parameter. Name of the specific configuration.
    type: str
  instanceId:
    description:
      - InstanceId query parameter. Instance Id of the
        specific configuration.
    type: str
  offset:
    description:
      - >
        Offset query parameter. The number of Rest/Webhook
        Subscription detail's to offset in the resultset
        whose default value 0.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of Rest/Webhook
        Subscription detail's to limit in the resultset
        whose default value 10.
    type: int
  sortBy:
    description:
      - SortBy query parameter. SortBy field name.
    type: str
  order:
    description:
      - Order query parameter.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Event Management
      GetRestWebhookSubscriptionDetails
    description: Complete reference of the GetRestWebhookSubscriptionDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-rest-webhook-subscription-details
notes:
  - SDK Method used are
    event_management.EventManagement.get_rest_webhook_subscription_details,
  - Paths used are
    get /dna/intent/api/v1/event/subscription-details/rest,
"""

EXAMPLES = r"""
---
- name: Get all Event Subscription Details Rest
  cisco.dnac.event_subscription_details_rest_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    name: string
    instanceId: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  elements: dict
  sample: >
    [
      {
        "instanceId": "string",
        "name": "string",
        "description": "string",
        "connectorType": "string",
        "url": "string",
        "method": "string",
        "trustCert": true,
        "headers": [
          {
            "name": "string",
            "value": "string"
          }
        ],
        "queryParams": [
          "string"
        ],
        "pathParams": [
          "string"
        ],
        "body": "string",
        "connectTimeout": 0,
        "readTimeout": 0,
        "serviceName": "string",
        "servicePort": "string",
        "namespace": "string",
        "proxyRoute": true
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: qos_policy_setting
short_description: Resource module for Qos Policy Setting
description:
  - Manage operation update of the resource Qos Policy
    Setting.
  - API to update the application QoS policy setting.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deployByDefaultOnWiredDevices:
    description: Flag to indicate whether QoS policy
      should be deployed automatically on wired network
      device when it is provisioned. This would be only
      applicable for cases where the network device
      is assigned to a site where a QoS policy has been
      configured.
    type: bool
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Application
      Policy UpdatesTheApplicationQoSPolicySetting
    description: Complete reference of the UpdatesTheApplicationQoSPolicySetting
      API.
    link: https://developer.cisco.com/docs/dna-center/#!updates-the-application-qo-s-policy-setting
notes:
  - SDK Method used are
    application_policy.ApplicationPolicy.updates_the_application_qo_s_policy_setting,
  - Paths used are
    put /dna/intent/api/v1/qosPolicySetting,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.qos_policy_setting:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    deployByDefaultOnWiredDevices: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: organizations_inventory_onboarding_cloud_monitoring_prepare
short_description: Resource module for organizations _inventory _onboarding _cloud _monitoring _prepare
description:
  - Manage operation create of the resource organizations _inventory _onboarding _cloud _monitoring _prepare. - > Initiates or updates an import
    session. An import ID will be generated and used when you are ready to commit the import.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module
author: Francisco Munoz (@fmunoz)
options:
  devices:
    description: A set of devices to import (or update).
    elements: dict
    suboptions:
      sudi:
        description: Device SUDI certificate.
        type: str
      tunnel:
        description: TLS Related Parameters.
        suboptions:
          certificateName:
            description: Name of the configured TLS certificate.
            type: str
          localInterface:
            description: Number of the vlan expected to be used to connect to the cloud.
            type: int
          loopbackNumber:
            description: Number of the configured Loopback Interface used for TLS overlay.
            type: int
          name:
            description: Name of the configured TLS tunnel.
            type: str
        type: dict
      user:
        description: User parameters.
        suboptions:
          username:
            description: The name of the device user for Meraki monitoring.
            type: str
        type: dict
      vty:
        description: VTY Related Parameters.
        suboptions:
          accessList:
            description: AccessList details.
            suboptions:
              vtyIn:
                description: VTY in ACL.
                suboptions:
                  name:
                    description: Name.
                    type: str
                type: dict
              vtyOut:
                description: VTY out ACL.
                suboptions:
                  name:
                    description: Name.
                    type: str
                type: dict
            type: dict
          authentication:
            description: VTY AAA authentication.
            suboptions:
              group:
                description: Group Details.
                suboptions:
                  name:
                    description: Group Name.
                    type: str
                type: dict
            type: dict
          authorization:
            description: VTY AAA authorization.
            suboptions:
              group:
                description: Group Details.
                suboptions:
                  name:
                    description: Group Name.
                    type: str
                type: dict
            type: dict
          endLineNumber:
            description: Ending line VTY number.
            type: int
          rotaryNumber:
            description: SSH rotary number.
            type: int
          startLineNumber:
            description: Starting line VTY number.
            type: int
        type: dict
    type: list
  options:
    description: Additional options for the import.
    suboptions:
      skipCommit:
        description: Flag to skip adding the device to RDM.
        type: bool
    type: dict
  organizationId:
    description: OrganizationId path parameter. Organization ID.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for organizations createOrganizationInventoryOnboardingCloudMonitoringPrepare
    description: Complete reference of the createOrganizationInventoryOnboardingCloudMonitoringPrepare API.
    link: https://developer.cisco.com/meraki/api-v1/#!create-organization-inventory-onboarding-cloud-monitoring-prepare
notes:
  - SDK Method used are
    organizations.Organizations.create_organization_inventory_onboarding_cloud_monitoring_prepare,
  - Paths used are
    post /organizations/{organizationId}/inventory/onboarding/cloudMonitoring/prepare,
"""

EXAMPLES = r"""
- name: Create
  cisco.meraki.organizations_inventory_onboarding_cloud_monitoring_prepare:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    devices:
      - sudi: '-----BEGIN CERTIFICATE----- MIIEKjCCAxKgAwIBAgIRANb+lsED3eb4+6YKLFFYqEkwDQYJKoZIhvcNAQELBQAw
          gYcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIDApDYWxpZm9ybmlhMREwDwYDVQQHDAhT YW4gSm9zZTEcMBoGA1UECgwTQ2lzY28gU3lzdGVtcywgSW5jLjESMBAGA1UECwwJ
          RE5BU3BhY2VzMR4wHAYDVQQDDBVjaXNjby5vcGVucm9hbWluZy5vcmcwHhcNMjAx MTA1MjEzMzM1WhcNMjExMTA1MjIzMzM1WjCBpDEcMBoGCgmSJomT8ixkAQETDGRu
          YXNwYWNlczpVUzELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMQ4wDAYDVQQKEwVD aXNjbzEcMBoGA1UECxMTV0JBOldSSVggRW5kLUVudGl0eTE8MDoGA1UEAxMzNjQ3
          MDcwNDM4NDQ5NjQxMjAwMDAuMTg4MzQuaHMuY2lzY28ub3BlbnJvYW1pbmcub3Jn MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoqjP9QgRGyUO3p7SH9QK
          uTq6UYK7nAyjImgS4yQxeBkyZ5f2EUkX8m/AOcewpPxxPBhjPKRwxGeX3S50ksiA ayFomUeslR0S0Z7RN9rzJa+CFyi9MwWIHMbLgXpB8tsSpgTAqwrzoTzOGq9fgC6u
          pZhdZrBkg3FeJgD88goCi9mZDsY2YAoeGRLFJ2fR8iICqIVQy+Htq9pE22WBLpnS KjL3+mR9FArHNFtWlhKF2YHMUqyHHrnZnF/Ns7QNoMMF7/CK18iAKgnb+2wuGKM2
          aEMddOeOTtz+i/rgjkp/RGMt011EdCsso0/cTo9qqX/bxOOCE4/Mne/ChMkQPnNU CwIDAQABo3IwcDAJBgNVHRMEAjAAMB8GA1UdIwQYMBaAFIG+4l5yiB01gP0sw4ML
          USopqYcuMB0GA1UdDgQWBBSby1T9leYVOVVdOZXiHCSaDDEMiDAOBgNVHQ8BAf8E BAMCBaAwEwYDVR0lBAwwCgYIKwYBBQUHAwIwDQYJKoZIhvcNAQELBQADggEBAEyE
          1mjSUyY6uNp6W4l20w7SskALSJDRKkOeZxAgF3VMxlsCuEl70s9oEfntwIpyQtSa jON/9yJHbwm/Az824bmk8Dc7AXIPhay+dftXb8j529gPuYB9AKoPNg0NctkyYCQh
          a/3YQVdDWX7XgmEiXkL57M7G6+IdcPDONLArfjOcT9qHdkVVq1AIjlMSx3OQQmm/ uoLb/G9q/97QA2/l8shG/Na8HjVqGLcl5TNZdbNhs2w9ogxr/GNzqdvym6RQ8vT/
          UR2n+uwH4n1MUxmHYYeyot5dnIV1IJ6hQ54JAncM9HvCLFk1WHz6RKshQUCuPBiJ wTw70BVktzJnb0VLeDg=
          -----END CERTIFICATE-----'
        tunnel:
          certificateName: DeviceSUDI
          localInterface: 1
          loopbackNumber: 1000
          name: MERAKI
        user:
          username: Meraki
        vty:
          accessList:
            vtyIn:
              name: MERAKI_IN
            vtyOut:
              name: MERAKI_OUT
          authentication:
            group:
              name: ''
          authorization:
            group:
              name: MERAKI
          endLineNumber: 17
          rotaryNumber: 50
          startLineNumber: 16
    options:
      skipCommit: false
    organizationId: string
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: list
  sample: >
    [
      {
        "configParams": {
          "cloudStaticIp": "string",
          "tunnel": {
            "host": "string",
            "mode": "string",
            "name": "string",
            "port": "string",
            "rootCertificate": {
              "content": "string",
              "name": "string"
            }
          },
          "user": {
            "publicKey": "string",
            "secret": {
              "hash": "string"
            },
            "username": "string"
          }
        },
        "deviceId": "string",
        "message": "string",
        "status": "string",
        "udi": "string"
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_config_files_info
short_description: Information module for Network Device
  Config Files
description:
  - Get all Network Device Config Files. - > Retrieves
    the list of network device configuration file details,
    sorted by createdTime in descending order. Use /intent/api/v1/networkDeviceConfigFiles/{id}/downloadMasked
    to download masked configurations, or /intent/api/v1/networkDeviceConfigFiles/{id}/downloadUnmasked
    for unmasked configurations.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. Unique identifier (UUID)
        of the configuration file.
    type: str
  networkDeviceId:
    description:
      - >
        NetworkDeviceId query parameter. Unique identifier
        (UUID) of the network devices. The number of
        networkDeviceId(s) must not exceed 5.
    type: str
  fileType:
    description:
      - >
        FileType query parameter. Type of device configuration
        file.Available values 'RUNNINGCONFIG', 'STARTUPCONFIG',
        'VLAN'.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page; the first record is numbered
        1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to be retrieved defaults to 500 if not specified,
        with a maximum allowed limit of 500.
    type: int
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Configuration
      Archive GetNetworkDeviceConfigurationFileDetails
    description: Complete reference of the GetNetworkDeviceConfigurationFileDetails
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-device-configuration-file-details
notes:
  - SDK Method used are
    configuration_archive.ConfigurationArchive.get_network_device_configuration_file_details,
  - Paths used are
    get /dna/intent/api/v1/networkDeviceConfigFiles,
"""

EXAMPLES = r"""
---
- name: Get all Network Device Config Files
  cisco.dnac.network_device_config_files_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    networkDeviceId: string
    fileType: string
    offset: 0
    limit: 0
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "networkDeviceId": "string",
          "versionId": "string",
          "fileType": "string",
          "createdBy": "string",
          "createdTime": 0
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_ap_profiles_info
short_description: Information module for Wireless Settings
  Ap Profiles
description:
  - Get all Wireless Settings Ap Profiles.
  - This API allows the user to get AP Profiles that
    captured in wireless settings design.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  limit:
    description:
      - >
        Limit query parameter. The number of records
        to show for this page. Default is 500 if not
        specified. Maximum allowed limit is 500.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to
        show for this page, the first record is numbered
        1.
    type: str
  apProfileName:
    description:
      - >
        ApProfileName query parameter. Employ this query
        parameter to obtain the details of the apProfiles
        corresponding to the provided apProfileName.
    type: str
requirements:
  - dnacentersdk >= 2.10.1
  - python >= 3.5
seealso:
  - name: Cisco DNA Center documentation for Wireless
      GetAPProfiles
    description: Complete reference of the GetAPProfiles
      API.
    link: https://developer.cisco.com/docs/dna-center/#!get-ap-profiles
notes:
  - SDK Method used are
    wireless.Wireless.get_ap_profiles,
  - Paths used are
    get /dna/intent/api/v1/wirelessSettings/apProfiles,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Settings Ap Profiles
  cisco.dnac.wireless_settings_ap_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    limit: string
    offset: string
    apProfileName: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "apProfileName": "string",
          "description": "string",
          "remoteWorkerEnabled": true,
          "managementSetting": {
            "authType": "string",
            "dot1xUsername": "string",
            "dot1xPassword": "string",
            "sshEnabled": true,
            "telnetEnabled": true,
            "managementUserName": "string",
            "managementPassword": "string",
            "managementEnablePassword": "string",
            "cdpState": true
          },
          "awipsEnabled": true,
          "awipsForensicEnabled": true,
          "rogueDetectionSetting": {
            "rogueDetection": true,
            "rogueDetectionMinRssi": 0,
            "rogueDetectionTransientInterval": 0,
            "rogueDetectionReportInterval": 0
          },
          "pmfDenialEnabled": true,
          "meshEnabled": true,
          "meshSetting": {
            "bridgeGroupName": "string",
            "backhaulClientAccess": true,
            "range": 0,
            "ghz5BackhaulDataRates": "string",
            "ghz24BackhaulDataRates": "string",
            "rapDownlinkBackhaul": "string"
          },
          "apPowerProfileName": "string",
          "calendarPowerProfiles": {
            "powerProfileName": "string",
            "schedulerType": "string",
            "duration": {
              "schedulerStartTime": "string",
              "schedulerEndTime": "string",
              "schedulerDay": [
                "string"
              ],
              "schedulerDate": [
                "string"
              ]
            }
          },
          "countryCode": "string",
          "timeZone": "string",
          "timeZoneOffsetHour": 0,
          "timeZoneOffsetMinutes": 0,
          "clientLimit": 0
        }
      ],
      "version": "string"
    }
"""
